firebase_pagination_plus library
Classes
- FilterModel
-
A class for creating a search filter model in
FirestorePagination - FirestorePaginationPlus
- A StreamBuilder that automatically loads more data when the user scrolls to the bottom.
- RealtimeDBPaginationPlus
- A StreamBuilder that automatically loads more data when the user scrolls to the bottom.
- WrapOptions
- The properties of the Wrap widget in the ViewType.wrap view.
Enums
- ViewType
- The ScrollView to use for the loaded data.